RSpec.describe SimpleHmac::Helper do
  context '#authentication_headers' do
    before do
      @signer = Object.new
      @signer.extend SimpleHmac::Helper
    end

    it 'returns the correct GET headers' do
      Timecop.freeze do
        expect(@signer).to receive(:hmac_token).and_return 'hmac_token'
        h = @signer.authentication_headers('GET', nil, nil, '/something', 'my_key', 'my_secret', auth_prefix: 'TEST')
        expect(h).to match({
          'Date' => Time.now.httpdate,
          'Content-Type' => 'text/plain',
          'Content-MD5' => '',
          'Authorization' => "TEST my_key:hmac_token"
        })
      end
    end

    it 'returns the correct POST headers' do
      Timecop.freeze do
        expect(@signer).to receive(:hmac_token).and_return 'hmac_token'
        h = @signer.authentication_headers('POST', 'application/json', '{a: 1}', '/something', 'my_key', 'my_secret', auth_prefix: 'TEST')
        expect(h).to match({
          'Date' => Time.now.httpdate,
          'Content-Type' => 'application/json',
          'Content-MD5' => 'B9JGFlnJCn1YCMEwtd2eFA==',
          'Authorization' => "TEST my_key:hmac_token"
        })
      end
    end
  end
end
