RSpec.describe SimpleHmac::Helper do
  context '#hmac_token' do
    let(:secret) { 'SECRET CODE' }

    let(:signer) { Object.new.tap { |o| o.extend SimpleHmac::Helper } }

    it 'should use default values for GET' do
      actual = signer.hmac_token(:get, 'application/json', '', 'http://example.com/hello', 'Mon, 16 Feb 2015 11:06:40 GMT', secret)

      string_to_sign = ['GET', 'application/json', '', '/hello', 'Mon, 16 Feb 2015 11:06:40 GMT'].join("\n")
      expected = signer.sign_string(string_to_sign, secret)

      expect(actual).to eq(expected)
    end

    describe '#sign_string' do
      it 'is the base64 encoded HMAC' do
        string = (0...50).map { ('a'..'z').to_a[rand(26)] }.join
        expected = Base64.strict_encode64(OpenSSL::HMAC.digest('sha256', secret, string))
        actual = signer.sign_string(string, secret, 'sha256')
        expect(actual).to eq expected
      end
    end
  end
end
