require 'rest-client'

RSpec.describe RestClient::Request do
  context '#sign!' do
    let!(:req) do
      RestClient::Request.new({
        url: 'http://example.com/something',
        method: :post,
        headers: { accept: :json, content_type: :json },
        payload: '{a: 1}'
      })
    end

    it 'is signed' do
      Timecop.freeze do
        expect(req).to receive(:hmac_token).and_return 'hmac_token'
        req.sign!('my_key', 'my_secret')
        expect(req.processed_headers).to match({
          'Date' => Time.now.httpdate,
          'Accept' => 'application/json',
          'Accept-Encoding' => 'gzip, deflate',
          'Authorization' => 'WIZYPAY my_key:hmac_token',
          'Content-Length' => '6',
          'Content-MD5' => 'B9JGFlnJCn1YCMEwtd2eFA==',
          'Content-Type' => 'application/json'
        })
      end
    end
  end
end
